@@ -24,10 +24,10 @@
  * DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
  *---------------------------------------------------------------------------
  * $File: //depot/povray/3.6-release/source/sor.cpp $
- * $Revision: #3 $
- * $Change: 3032 $
- * $DateTime: 2004/08/02 18:43:41 $
- * $Author: chrisc $
+ * $Revision: #2 $
+ * $Change: 2939 $
+ * $DateTime: 2004/07/04 13:43:26 $
+ * $Author: root $
  * $Log$
  *****************************************************************************/
 
@@ -94,6 +94,7 @@
 #include "frame.h"
 #include "povray.h"
 #include "vector.h"
+#include "povproto.h"
 #include "bbox.h"
 #include "polysolv.h"
 #include "matrices.h"
